JustifyContent

Enum JustifyContent 

pub enum JustifyContent {
    Start,
    Center,
    End,
    SpaceBetween,
    SpaceEvenly,
}
Re-export all transformer model types for convenience.

This includes types like Element, Attribute, and other core data structures used in the template system. Content justification along the main axis in flexbox-style layouts.

Controls how space is distributed between and around child elements along the main axis.

Variants



Start

Align items to the start of the container. This is the default.



Center

Center items along the main axis.



End

Align items to the end of the container.



SpaceBetween

Distribute items with equal space between them.



SpaceEvenly

Distribute items with equal space around them.