Module prelude

Module prelude 

Prelude module that re-exports commonly used traits.

This module is automatically imported when you use hyperchad_template::container, so you don’t need to manually import these traits.

This module is designed to be imported via use hyperchad_template::prelude::* to bring all commonly needed traits and types into scope. Re-exports the traits, helpers, and crate aliases most templates need.

Re-exports

pub use crate as hyperchad_template;
pub use crate::ContainerVecExt;
pub use crate::ContainerVecMethods;
pub use crate::IntoActionEffect;
pub use crate::IntoBorder;
pub use crate::ToBool;
pub use crate::calc;
pub use crate::fx;
pub use crate::actions as hyperchad_actions;
pub use crate::color as hyperchad_color;
pub use crate::template_actions_dsl as hyperchad_template_actions_dsl;
pub use crate::transformer as hyperchad_transformer;
pub use crate::transformer_models as hyperchad_transformer_models;