ContainerVecExt

Trait ContainerVecExt 

pub trait ContainerVecExt {
    // Required methods
    fn display_to_string(
        &self,
        with_debug_attrs: bool,
        wrap_raw_in_element: bool,
    ) -> Result<String, Box<dyn Error>>;
    fn display_to_string_pretty(
        &self,
        with_debug_attrs: bool,
        wrap_raw_in_element: bool,
    ) -> Result<String, Box<dyn Error>>;
    fn into_string(self) -> String;
    fn to_string(&self) -> String;
}
Extension trait to add missing methods to Vec<Container>

Required Methods

fn display_to_string( &self, with_debug_attrs: bool, wrap_raw_in_element: bool, ) -> Result<String, Box<dyn Error>>

Convert the containers to a string representation with optional debug attributes.

Errors
  • If the container could not be converted to a string.
fn display_to_string_pretty( &self, with_debug_attrs: bool, wrap_raw_in_element: bool, ) -> Result<String, Box<dyn Error>>

Convert the containers to a pretty-printed string with optional debug attributes.

Errors
  • If the container could not be converted to a string.
fn into_string(self) -> String

Convert the containers to an HTML string, consuming self.

fn to_string(&self) -> String

Convert the containers to an HTML string.

Implementations on Foreign Types

Source

impl ContainerVecExt for Vec<Container>

Source

fn display_to_string( &self, with_debug_attrs: bool, wrap_raw_in_element: bool, ) -> Result<String, Box<dyn Error>>

Source

fn display_to_string_pretty( &self, with_debug_attrs: bool, wrap_raw_in_element: bool, ) -> Result<String, Box<dyn Error>>

Source

fn into_string(self) -> String

Source

fn to_string(&self) -> String

Implementors