pub trait ContainerVecExt {
// Required methods
fn display_to_string(
&self,
with_debug_attrs: bool,
wrap_raw_in_element: bool,
) -> Result<String, Box<dyn Error>>;
fn display_to_string_pretty(
&self,
with_debug_attrs: bool,
wrap_raw_in_element: bool,
) -> Result<String, Box<dyn Error>>;
fn into_string(self) -> String;
fn to_string(&self) -> String;
}Expand description
Extension trait to add missing methods to Vec<Container>
Required Methods
Sourcefn display_to_string(
&self,
with_debug_attrs: bool,
wrap_raw_in_element: bool,
) -> Result<String, Box<dyn Error>>
fn display_to_string( &self, with_debug_attrs: bool, wrap_raw_in_element: bool, ) -> Result<String, Box<dyn Error>>
Convert the containers to a string representation with optional debug attributes.
Errors
- If the container could not be converted to a string.
Sourcefn display_to_string_pretty(
&self,
with_debug_attrs: bool,
wrap_raw_in_element: bool,
) -> Result<String, Box<dyn Error>>
fn display_to_string_pretty( &self, with_debug_attrs: bool, wrap_raw_in_element: bool, ) -> Result<String, Box<dyn Error>>
Convert the containers to a pretty-printed string with optional debug attributes.
Errors
- If the container could not be converted to a string.
Sourcefn into_string(self) -> String
fn into_string(self) -> String
Convert the containers to an HTML string, consuming self.